@@ -1,283 +1,283 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="ja" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
 <context>
     <name>MXDateTime</name>
     <message>
-        <location filename="datetime.ui" line="20"/>
-        <location filename="datetime.cpp" line="596"/>
+        <location filename="../datetime.ui" line="20"/>
+        <location filename="../datetime.cpp" line="604"/>
         <source>MX Date &amp; Time</source>
         <translation>MX Date &amp; Time</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="26"/>
+        <location filename="../datetime.ui" line="26"/>
         <source>Close</source>
         <translation>閉じる</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="40"/>
+        <location filename="../datetime.ui" line="40"/>
         <source>Help</source>
         <translation>ヘルプ</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="73"/>
+        <location filename="../datetime.ui" line="73"/>
         <source>Apply</source>
         <translation>適用</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="100"/>
+        <location filename="../datetime.ui" line="100"/>
         <source>About...</source>
         <translation>情報...</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="124"/>
+        <location filename="../datetime.ui" line="124"/>
         <source>Date &amp;&amp; Time</source>
         <translation>日付 &amp;&amp; 時間</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="192"/>
+        <location filename="../datetime.ui" line="192"/>
         <source>H:mm:ss</source>
         <translation>時:分:秒</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="278"/>
-        <location filename="datetime.cpp" line="296"/>
-        <location filename="datetime.cpp" line="303"/>
+        <location filename="../datetime.ui" line="278"/>
+        <location filename="../datetime.cpp" line="296"/>
+        <location filename="../datetime.cpp" line="303"/>
         <source>Hardware Clock</source>
         <translation>ハードウェアクロック</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="284"/>
+        <location filename="../datetime.ui" line="284"/>
         <source>Hardware Clock tools</source>
         <translation>ハードウェアクロックのツール</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="290"/>
+        <location filename="../datetime.ui" line="290"/>
         <source>Obtain information from the Hardware Clock and present it in the box below.</source>
         <translation>ハードウェアクロックから情報を入手し、下のボックスに示します。</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="293"/>
+        <location filename="../datetime.ui" line="293"/>
         <source>Read the Hardware Clock</source>
         <translation>ハードウェアクロックの取得</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="300"/>
+        <location filename="../datetime.ui" line="303"/>
         <source>Apply systematic drift corrections to the Hardware Clock.</source>
         <translation>ハードウェアクロックにシステマティックなドリフト補正を適用します。</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="303"/>
+        <location filename="../datetime.ui" line="306"/>
         <source>Drift Adjust</source>
         <translation>ドリフト補正</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="323"/>
+        <location filename="../datetime.ui" line="329"/>
         <source>Time transfer</source>
         <translation>時間の転送</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="329"/>
+        <location filename="../datetime.ui" line="335"/>
         <source>Immediately set the System Clock to match the current time registered by the Hardware Clock.</source>
         <translation>ハードウェアクロックに登録されている現在時刻に合わせて、システムクロックを直ちに設定します。</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="332"/>
+        <location filename="../datetime.ui" line="338"/>
         <source>Hardware Clock to System Clock</source>
         <translation>ハードウェアクロックをシステムクロックに</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="339"/>
+        <location filename="../datetime.ui" line="348"/>
         <source>Immediately set the Hardware Clock to match the current time registered by the System Clock.</source>
         <translation>システムクロックに登録されている現在の時刻に合わせて、直ちにハードウェアクロックを設定します。</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="342"/>
+        <location filename="../datetime.ui" line="351"/>
         <source>System Clock to Hardware Clock</source>
         <translation>システムクロックをハードウェアクロックに</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="349"/>
+        <location filename="../datetime.ui" line="361"/>
         <source>Update the drift factor for the Hardware Clock when it is being set.</source>
         <translation>ハードウェアクロックが設定されている時、ドリフト係数を更新します。</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="352"/>
+        <location filename="../datetime.ui" line="364"/>
         <source>Update the drift</source>
         <translation>ドリフトを更新</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="362"/>
+        <location filename="../datetime.ui" line="374"/>
         <source>Time zone for the Hardware Clock</source>
         <translation>ハードウェアクロックのタイムゾーン</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="368"/>
+        <location filename="../datetime.ui" line="380"/>
         <source>Local time</source>
         <translation>現地時刻</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="371"/>
+        <location filename="../datetime.ui" line="383"/>
         <source>Local</source>
         <translation>地域</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="378"/>
+        <location filename="../datetime.ui" line="390"/>
         <source>Universally Coordinated Time (or Greenwich Meridian Time)</source>
         <translation>世界標準時（グリニッジ標準時）</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="381"/>
+        <location filename="../datetime.ui" line="393"/>
         <source>UTC</source>
         <translation>UTC</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="421"/>
+        <location filename="../datetime.ui" line="433"/>
         <source>Network Time</source>
         <translation>Network Time</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="427"/>
+        <location filename="../datetime.ui" line="439"/>
         <source>Move the selected item down</source>
         <translation>選択したアイテムを下に移動</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="438"/>
+        <location filename="../datetime.ui" line="450"/>
         <source>Move the selected item up</source>
         <translation>選択したアイテムを上に移動</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="449"/>
+        <location filename="../datetime.ui" line="461"/>
         <source>Remove the current item from the list</source>
         <translation>一覧から現在のアイテムを削除</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="460"/>
+        <location filename="../datetime.ui" line="472"/>
         <source>Add an item to the list</source>
         <translation>一覧にアイテムを追加</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="486"/>
+        <location filename="../datetime.ui" line="498"/>
         <source>Automatically update the System Clock with NTP servers:</source>
         <translation>NTPサーバーでシステムクロックを自動的に更新：</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="493"/>
+        <location filename="../datetime.ui" line="505"/>
         <source>Immediately update the system clock with NTP servers.</source>
         <translation>NTPサーバーでシステムクロックを今すぐ更新</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="496"/>
+        <location filename="../datetime.ui" line="508"/>
         <source>Update Now</source>
         <translation>今すぐ更新</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="505"/>
+        <location filename="../datetime.ui" line="520"/>
         <source>List of NTP servers to use.</source>
         <translation>利用可能な NTP サーバー一覧</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="521"/>
+        <location filename="../datetime.ui" line="536"/>
         <source>Type</source>
         <translation>種類</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="526"/>
+        <location filename="../datetime.ui" line="541"/>
         <source>Address</source>
         <translation>アドレス</translation>
     </message>
     <message>
-        <location filename="datetime.ui" line="531"/>
+        <location filename="../datetime.ui" line="546"/>
         <source>Options</source>
         <translation>オプション</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="270"/>
+        <location filename="../datetime.cpp" line="270"/>
         <source>Reading...</source>
         <translation>読み込み中...</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="284"/>
+        <location filename="../datetime.cpp" line="284"/>
         <source>Adjusting...</source>
         <translation>調整中...</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="296"/>
-        <location filename="datetime.cpp" line="303"/>
+        <location filename="../datetime.cpp" line="296"/>
+        <location filename="../datetime.cpp" line="303"/>
         <source>System Clock</source>
         <translation>システムクロック</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="309"/>
+        <location filename="../datetime.cpp" line="309"/>
         <source>The %1 time was transferred to the %2.</source>
         <translation>%1 の時間を %2 に転送しました。</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="312"/>
+        <location filename="../datetime.cpp" line="312"/>
         <source>The %1 time could not be transferred to the %2.</source>
         <translation>%1 の時間を %2 に転送できません。</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="350"/>
+        <location filename="../datetime.cpp" line="352"/>
         <source>Updating...</source>
         <translation>更新中...</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="360"/>
+        <location filename="../datetime.cpp" line="365"/>
         <source>The system clock was updated successfully.</source>
         <translation>システムクロックの更新に成功しました。</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="362"/>
+        <location filename="../datetime.cpp" line="367"/>
         <source>The system clock could not be updated.</source>
         <translation>システムクロックは更新されませんでした。</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="364"/>
+        <location filename="../datetime.cpp" line="369"/>
         <source>None of the NTP servers on the list are currently enabled.</source>
         <translation>リスト上の NTP サーバーは現在有効ではありません。</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="595"/>
+        <location filename="../datetime.cpp" line="603"/>
         <source>About MX Date &amp; Time</source>
         <translation>MX Date &amp; Time について</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="596"/>
+        <location filename="../datetime.cpp" line="604"/>
         <source>Version: </source>
         <translation>バージョン: </translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="597"/>
+        <location filename="../datetime.cpp" line="605"/>
         <source>GUI program for setting the time and date in MX Linux</source>
         <translation>MX Linux で日時を設定する GUI プログラム</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="599"/>
+        <location filename="../datetime.cpp" line="607"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="600"/>
-        <location filename="datetime.cpp" line="614"/>
+        <location filename="../datetime.cpp" line="608"/>
+        <location filename="../datetime.cpp" line="622"/>
         <source>License</source>
         <translation>ライセンス</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="601"/>
+        <location filename="../datetime.cpp" line="609"/>
         <source>Changelog</source>
         <translation>更新履歴</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="602"/>
+        <location filename="../datetime.cpp" line="610"/>
         <source>Cancel</source>
         <translation>キャンセル</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="628"/>
+        <location filename="../datetime.cpp" line="636"/>
         <source>&amp;Close</source>
         <translation>閉じる(&amp;C)</translation>
     </message>
     <message>
-        <location filename="datetime.cpp" line="646"/>
+        <location filename="../datetime.cpp" line="654"/>
         <source>MX Date &amp; Time Help</source>
         <translation>MX Date &amp; Time のヘルプ</translation>
     </message>
